@@ -5,14 +5,21 @@
 
 # Standard library.
 from os.path import isfile
+# Required internal classes/functions.
+from tlnetcard_python.login import Login
+from tlnetcard_python.monitor.about.information import Information
 
 class Upgrade:
     """ Class for the Upgrade object. """
-    def __init__(self, login_object):
+    def __init__(self, login_object: Login) -> None:
         """ Initializes the Upgrade object. """
         self._login_object = login_object
         self._post_url = login_object.get_base_url() + "/delta/adm_upgrade"
-    def upgrade_snmp_firmware(self, path="ups-tl-01_12_05c.bin"):
+        self._information_object = Information(self._login_object)
+    def get_firmware_version(self) -> str:
+        """ GETs the current firmware version. """
+        return self._information_object.get_firmware_version()
+    def upgrade_snmp_firmware(self, path: str = "ups-tl-01_12_05c.bin") -> int:
         """ Upgrades SNMP Device Firmware. """
         # Testing if the file specified in path exists.
         if not isfile(path):
